@@ -15,6 +15,7 @@ class EutilEnum(str, Enum):
 
 class DbEnum(str, Enum):
     pubmed = 'pubmed'
+    pmc = 'pmc'
 
 
 class RetModeEnum(str, Enum):
@@ -28,3 +29,13 @@ class RetTypeEnum(str, Enum):
     abstract = 'abstract'
     docsum = 'docsum'
     medline = 'medline'
+
+
+class DownloadPathEnum(str, Enum):
+    updatefiles = 'updatefiles'
+    baseline = 'baseline'
+
+
+class DocTypeEnum(str, Enum):
+    pubmedArticleSet = 'PubmedArticleSet'
+    pmcArticleset = 'pmc-articleset'
